==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERSURVEYQUESTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERSURVEYQUESTIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERSURVEYQUESTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYQUESTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERSURVEYQUESTIONID_Type", propOrder = {
    "surveyquestioncode",
    "description"
})
public class CUSTOMERSURVEYQUESTIONID_Type {

    @XmlElement(name = "SURVEYQUESTIONCODE", required = true)
    protected String surveyquestioncode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété surveyquestioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSURVEYQUESTIONCODE() {
        return surveyquestioncode;
    }

    /**
     * Définit la valeur de la propriété surveyquestioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSURVEYQUESTIONCODE(String value) {
        this.surveyquestioncode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERSURVEYQUESTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERSURVEYQUESTIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERSURVEYQUESTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYQUESTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERSURVEYQUESTIONID_Type", propOrder = {
    "surveyquestioncode",
    "description"
})
public class CUSTOMERSURVEYQUESTIONID_Type {

    @XmlElement(name = "SURVEYQUESTIONCODE", required = true)
    protected String surveyquestioncode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the surveyquestioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSURVEYQUESTIONCODE() {
        return surveyquestioncode;
    }

    /**
     * Sets the value of the surveyquestioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSURVEYQUESTIONCODE(String value) {
        this.surveyquestioncode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
